# Changelog

<!--next-version-placeholder-->

## v4.6.2 (2022-06-24)
### Fix
* Add support for 1 atom xyz files... properly ([`b9c759a`](https://gitlab.com/jonkragskow/xyz_py/-/commit/b9c759ad30327e56cb2149a9c0d3963a69581f70))

## v4.6.1 (2022-06-24)
### Fix
* Support for 1 atom xyz files ([`3c2c53e`](https://gitlab.com/jonkragskow/xyz_py/-/commit/3c2c53edd1b439a2312c2b7d5b5516bfa2490dae))

## v4.6.0 (2022-05-17)


## v4.5.0 (2022-04-22)
### Feature
* Change rotate cli args to dgerees and add radians option ([`8798e44`](https://gitlab.com/jonkragskow/xyz_py/-/commit/8798e4453d43e72c174798dc84a0bb09dde40004))

## v4.4.0 (2022-04-22)
### Feature
* Add rotate cli ([`4c7fce1`](https://gitlab.com/jonkragskow/xyz_py/-/commit/4c7fce126db1f3f3cfe440936a129b72f503d6d8))

## v4.3.1 (2022-04-22)


## v4.3.0 (2022-04-22)
### Feature
* Add rotate cli and covalent and non-bonding radii ([`a5f328f`](https://gitlab.com/jonkragskow/xyz_py/-/commit/a5f328fbde65f988d6350d6fbb1852cb538071b0))

## v4.2.0 (2022-01-28)
### Feature
* Modify remove_numbers to remove letters after number from label e.g. H1a --> H ([`7840770`](https://gitlab.com/jonkragskow/xyz_py/-/commit/7840770b58557671a584ae31e8e95a5f88bbd437))

## v4.1.0 (2022-01-04)
### Feature
* Add centre of mass calculation and fix bug in bonds, angles and dihedrals code ([`924bcb5`](https://gitlab.com/jonkragskow/xyz_py/-/commit/924bcb5261a8d9d16ae3df91f49caf8e769ff631))

## v4.0.0 (2021-11-15)


## v3.0.0 (2021-11-12)
### Breaking
* <breaking change summary> ([`234c45f`](https://gitlab.com/jonkragskow/xyz_py/-/commit/234c45fd29e50fdb424fa6bbd428262523574dad))

### Documentation
* Update module level docstrings ([`08582a7`](https://gitlab.com/jonkragskow/xyz_py/-/commit/08582a757105b06b4657e2c43023dfab42203213))
* Add docstring to each file ([`2e9f75b`](https://gitlab.com/jonkragskow/xyz_py/-/commit/2e9f75b33c81b514dda8a97ee55a2fa430793f8b))

## v2.2.1 (2021-11-11)


## v2.2.0 (2021-11-11)
### Feature
* Add label indexing to load_xyz ([`5e4134f`](https://gitlab.com/jonkragskow/xyz_py/-/commit/5e4134f15ed9457bc148f50f093f191dc82f88eb))

## v2.1.0 (2021-11-09)
### Feature
* Add command line interface ([`40a22bb`](https://gitlab.com/jonkragskow/xyz_py/-/commit/40a22bbd6f5f3514bb5145ada9fae9a81793d9e6))

## v2.0.0 (2021-11-09)


## v1.0.0 (2021-11-09)

